*********************************
Partial evaluation of Python code
*********************************

.. image:: https://travis-ci.org/fjarri/peval.png?branch=master
    :target: https://travis-ci.org/fjarri/peval

.. image:: https://coveralls.io/repos/fjarri/peval/badge.png?branch=master
    :target: https://coveralls.io/r/fjarri/peval

Read more at the `project documentation page <http://peval.readthedocs.org>`_.
